
# spec file for package nginx-1.6x
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           nginx-1.6-passenger4
Version:        1.6.2
Release:        1.1

#
%define pkg_name nginx
#
%define ngx_prefix     %{_prefix}
%define ngx_sbindir    %{_sbindir}/nginx
%define ngx_conf_dir   %{_sysconfdir}/nginx
%define ngx_conf_path  %{ngx_conf_dir}/nginx.conf
%define ngx_log_dir    /var/log/nginx
%define ngx_error_log  %{ngx_log_dir}/error.log
%define ngx_access_log %{ngx_log_dir}/access.log
%define ngx_pid_path   /var/run/nginx.pid
%define ngx_lock_path  /var/run/nginx.lock
%define ngx_home       /var/lib/nginx
%define ngx_tmp_http   %{ngx_home}/tmp/
%define ngx_tmp_proxy  %{ngx_home}/proxy/
%define ngx_tmp_fcgi   %{ngx_home}/fastcgi/
%define ngx_tmp_scgi   %{ngx_home}/scgi/
%define ngx_tmp_uwsgi  %{ngx_home}/uwsgi/
%define ngx_user_group nginx
%define with_cpp_test   0
%define with_google_perftools 0
%if 0%{?suse_version} >= 1110
%define with_passenger 1
%define with_libatomic 1
%endif
#
Group:          Productivity/Networking/Web/Proxy
License:        BSD-2-Clause
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?with_cpp_test}
BuildRequires:  gcc-c++
%endif
BuildRequires:  gd-devel
BuildRequires:  GeoIP-devel
%if 0%{?with_google_perftools}
BuildRequires:  google-perftools-devel
%endif
%if 0%{?with_libatomic}
BuildRequires:  libatomic-ops-devel
%endif
BuildRequires:  libxslt-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
%if 0%{?with_passenger}
BuildRequires:	ruby
BuildRequires:  rubygem-passenger4-devel-static
# workaround for obs scheduler:
BuildRequires:  rubygem-rack-1_5
Recommends:     packageand(rubygem-passenger4:rubygem-passenger4-nginx)
%endif
PreReq:         %fillup_prereq
PreReq:         %insserv_prereq
PreReq:         pwdutils
Provides:       nginx = %{version}-%{release}
#
Conflicts:      nginx-0.5 nginx-0.6 nginx-0.7 nginx-0.8 nginx-0.9  nginx-1.0  nginx-1.2 nginx-1.3 nginx-1.4 nginx-1.5
%requires_eq    perl
#
Url:            http://nginx.net/
Source:         nginx-%{version}.tar.gz
Source1:        nginx.init
Source2:        nginx.logrotate
Source10:       local-nginx.conf
Source11:       default-website
# PATCH-FIX-UPSTREAM nginx-0.4.0-no_Werror.patch
Patch:          nginx-0.4.0-no_Werror.patch
# PATCH-FIX-UPSTREAM nginx-1.0.12-html.patch
Patch2:         nginx-1.0.12-html.patch
# PATCH-FIX-UPSTREAM nginx-1.3.8-perl_vendor_install.patch
Patch3:         nginx-1.3.8-perl_vendor_install.patch
# PATCH-FIX-UPSTREAM nginx-1.0.4_default_config.patch
Patch4:         nginx-1.5.0_default_config.patch
# PATCH for fixing docs/html path
Patch5:         nginx-1.0.15_docs.patch

Summary:        A HTTP server and IMAP/POP3 proxy server
%description
nginx [engine x] is a HTTP server and IMAP/POP3 proxy server written by Igor Sysoev.
It has been running on many heavily loaded Russian sites for more than two years.

Author:
-------
    Igor Sysoev

%prep
%setup -n %{pkg_name}-%{version}
%patch
%patch2
%patch3 -p1
%patch4
#%patch5

perl -pi -e 's|\r\n|\n|g' contrib/geo2nginx.pl

%build
%if 0%{?with_passenger}
ln -s %{_libdir}/ruby/gems/%{rb_ver}/gems/passenger-* passenger
%endif
./configure                                     \
  --prefix=%{ngx_prefix}/                      \
  --sbin-path=%{ngx_sbindir}                   \
  --conf-path=%{ngx_conf_path}                 \
  --error-log-path=%{ngx_error_log}            \
  --http-log-path=%{ngx_access_log}            \
  --pid-path=%{ngx_pid_path}                   \
  --lock-path=%{ngx_lock_path}                 \
  --http-client-body-temp-path=%{ngx_tmp_http} \
  --http-proxy-temp-path=%{ngx_tmp_proxy}      \
  --http-fastcgi-temp-path=%{ngx_tmp_fcgi}     \
  --http-uwsgi-temp-path=%{ngx_tmp_uwsgi}      \
  --http-scgi-temp-path=%{ngx_tmp_scgi}        \
  --user=nginx --group=nginx                   \
  --with-rtsig_module                          \
  --with-select_module                         \
  --with-poll_module                           \
  --with-ipv6                                  \
%if  0%{?suse_version} > 1110
  --with-file-aio                              \
%endif
  --with-http_ssl_module                       \
  --with-http_spdy_module                      \
  --with-http_realip_module                    \
  --with-http_addition_module                  \
  --with-http_xslt_module                      \
  --with-http_image_filter_module              \
  --with-http_geoip_module                     \
  --with-http_sub_module                       \
  --with-http_dav_module                       \
  --with-http_flv_module                       \
  --with-http_gzip_static_module               \
  --with-http_random_index_module              \
  --with-http_secure_link_module               \
  --with-http_degradation_module               \
  --with-http_stub_status_module               \
  --with-http_perl_module                      \
  --with-perl=%{_bindir}/perl                  \
  --with-mail                                  \
  --with-mail_ssl_module                       \
  --with-pcre                                  \
  %if 0%{?with_libatomic}
  --with-libatomic                             \
  %endif
  %if 0%{?with_passenger}
  --add-module=passenger/ext/nginx             \
  %endif
  %if 0%{?with_google_perftools}
  --with-google_perftools_module               \
  %endif
  %if 0%{?with_cpp_test}
  --with-cpp_test_module                       \
  %endif
  --with-md5=/usr                              \
  --with-sha1=/usr                             \
%if 0%{?suse_version} > 1000 || 0%{?fedora_version} > 4 || 0%{?mandriva_version} > 2006
  --with-cc-opt="%{optflags} -fstack-protector"
%else
  --with-cc-opt="%{optflags}"
%endif
%{__make}

%install
%makeinstall
%perl_process_packlist
#
%{__install} -d -m 0750 %{buildroot}%{ngx_home}/{,tmp,proxy,fastcgi,scgi,uwsgi}
#
%{__install} -D -m 0755 %{S:1} %{buildroot}%{_sysconfdir}/init.d/%{pkg_name}
%{__ln_s} -f %{_sysconfdir}/init.d/%{pkg_name} %{buildroot}%{_sbindir}/rc%{pkg_name}

%{__install} -D -m 0644 %{S:2} %{buildroot}%{_sysconfdir}/logrotate.d/%{pkg_name}

%{__rm} %{buildroot}/srv/www/htdocs/index.html

# local configuration
%{__mv} %{buildroot}%{ngx_conf_dir}/nginx.conf %{buildroot}%{ngx_conf_dir}/nginx.conf.distrib
%{__install} -D -m 0644 %{S:10} %{buildroot}%{ngx_conf_dir}/nginx.conf
%{__install} -D -m 0644 %{S:11} %{buildroot}%{ngx_conf_dir}/sites-available/default
%{__mkdir_p} %{buildroot}%{ngx_conf_dir}/conf.d
%{__mkdir_p} %{buildroot}%{ngx_conf_dir}/sites-enabled/
%{__ln_s} -f %{ngx_conf_dir}/sites-available/default %{buildroot}%{ngx_conf_dir}/sites-enabled/

%post
%fillup_and_insserv %{pkg_name}

%preun
%stop_on_removal %{pkg_name}

%postun
%restart_on_update %{pkg_name}
%{insserv_cleanup}

%clean
%{__rm} -rf %{buildroot}

%pre
/usr/sbin/groupadd -r %{ngx_user_group} &>/dev/null ||:
/usr/sbin/useradd -g %{ngx_user_group} -s /bin/false -r -c "user for %{ngx_user_group}" -d %{ngx_home} %{ngx_user_group} &>/dev/null ||:

%files
%defattr(-,root,root,-)
%dir %{ngx_conf_dir}/
%config(noreplace) %{ngx_conf_dir}/koi-utf
%config(noreplace) %{ngx_conf_dir}/koi-win
%config(noreplace) %{ngx_conf_dir}/fastcgi_params
%config(noreplace) %{ngx_conf_dir}/fastcgi_params.default
%config(noreplace) %{ngx_conf_dir}/mime.types
%config(noreplace) %{ngx_conf_dir}/mime.types.default
%config(noreplace) %{ngx_conf_dir}/nginx.conf
%config(noreplace) %{ngx_conf_dir}/nginx.conf.default
%config(noreplace) %{ngx_conf_dir}/nginx.conf.distrib
%config(noreplace) %{ngx_conf_dir}/fastcgi.conf
%config(noreplace) %{ngx_conf_dir}/fastcgi.conf.default
%config(noreplace) %{ngx_conf_dir}/win-utf
%config(noreplace) %{ngx_conf_dir}/scgi_params
%config(noreplace) %{ngx_conf_dir}/scgi_params.default
%config(noreplace) %{ngx_conf_dir}/uwsgi_params
%config(noreplace) %{ngx_conf_dir}/uwsgi_params.default
%dir %{ngx_conf_dir}/sites-available
%config(noreplace) %{ngx_conf_dir}/sites-available/*
%dir %{ngx_conf_dir}/sites-enabled
%config(noreplace) %{ngx_conf_dir}/sites-enabled/*
%{perl_vendorarch}/auto/nginx/
%{perl_vendorarch}/nginx.pm
%{ngx_sbindir}
%{_mandir}/man3/nginx.3pm*
/srv/www/htdocs/50x.html
%if 0%{?suse_version} && 0%{?suse_version} < 1140
%{_localstatedir}/adm/perl-modules/%{name}
%endif
%{_sysconfdir}/init.d/%{pkg_name}
%{_sbindir}/rc%{pkg_name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{pkg_name}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) /var/log/nginx/
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_home}/
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_http}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_proxy}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_fcgi}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_scgi}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_uwsgi}
%doc CHANGES*
%doc conf/ contrib/

%changelog
